# Exceptions

## Base

::: aiobsidian.ObsidianError

## CLI exceptions

::: aiobsidian.CLIError

::: aiobsidian.BinaryNotFoundError

::: aiobsidian.CommandError

::: aiobsidian.CLITimeoutError

## REST API exceptions

::: aiobsidian.APIError

::: aiobsidian.AuthenticationError

::: aiobsidian.NotFoundError
